@@ -7,7 +7,9 @@ from mahabharata.services.poet_service.query import get_all_verses_by_author, al
 @click.option("--all", "-a", help="list all in scope, overides limit", is_flag=True)
 @click.option("--limit", "-l", help="Limit poems to 'N', where 0 < N <= 10", default=1)
 @click.option("--collabs", "-c", help="Show collaborators with poem", is_flag=True)
-def query_poem(author: str, all: bool, limit: int, collabs: bool) -> None:
+def verses(author: str, all: bool, limit: int, collabs: bool) -> None:
+    """Query Mahabharata poems, the default behaviour will give you all verses in list with there authors."""
+
     def get_quote(iterable, all):
         for index, verse in enumerate(iterable):
             if index == limit and not all:
